#! /bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for vbox services on EIS/FAIR
#
# Copyright (c) 2002-2016 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2002-02-27  jed
# Last Update:  $Id: preinstall.sh 43656 2016-10-08 17:37:39Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# include eislib etc.
. /var/install/include/eislib

# file names
module_name='vbox'

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2> /tmp/${module_name}-preinstall.sh-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
archivefile=/var/run/${module_name}-backup.tgz
deinstallfile=/var/install/deinstall/${module_name}
packagefile=/var/install/packages/${module_name}

mecho --info "running preinstall.sh ..."

# check base version
if [ -f ${packagefile} ]
then
    base_version="`grep "<require-package>base " ${packagefile} | sed 's#^.*<require-package>base *\(.*\) *</require-.*$#\1#'`"
else
    base_version='2.7.7'
fi

installed_version=`/var/install/bin/check-version base ${base_version}`

case ${installed_version} in
    not-installed|new ) # wrong version
        mecho --warn "required base package v${base_version} not installed - installation aborted."
        /var/install/bin/anykey
        exit 1
        ;;
    * ) # installed / old
        ;;
esac

# check mail version
no_mail=0
no_vmail=0
no_ssmtp=0

installed_version=`/var/install/bin/check-version mail 1.11.3`

case ${installed_version} in
    not-installed|new ) # wrong version
        no_mail=1
        ;;
    * ) # installed / old
        ;;
esac

if [ ${no_mail} -eq 1 ]
then
    # check vmail version
    installed_version=`/var/install/bin/check-version vmail 1.6.0`

    case ${installed_version} in
        not-installed|new ) # wrong version
            no_vmail=1
            ;;
        * ) # installed / old
            ;;
    esac

    if [ ${no_vmail} -eq 1 ]
    then
        # check ssmtp version
        installed_version=`/var/install/bin/check-version ssmtp 1.0.0`

        case ${installed_version} in
            not-installed|new ) # wrong version
                no_ssmtp=1
                ;;
            * ) # installed / old
                ;;
        esac
    fi
fi

if [ ${no_mail} -eq 1 -a ${no_vmail} -eq 1 -a ${no_ssmtp} -eq 1 ]
then
    mecho --error "No mail package (mail|vmail|ssmtp) has been installed - installation aborted."
    mecho --error "Please install mail package v1.11.3 or newer, vmail package v1.6.0 or newer or"
    mecho --error "ssmtp package v1.0.0 or newer."
    anykey
    exit 1
fi

if [ -d /var/spool/${module_name} ]
then
    mecho "archiving files from /var/spool/${module_name} ..."
    cd /
    tar czf ${archivefile} var/spool/${module_name}/*
fi

# backup existing file
if [ -f ${configfile} ]
then
    mecho "saving previous configuration file to ${installfile} ..."
    /var/install/bin/backup-file --quiet ${configfile}
    cp ${configfile} ${installfile}
fi

# deinstall old software
if [ -f ${deinstallfile} ]
then
    # make sure that the sox binary is not removed erroneously
    grep -v "testroot/usr/bin/sox" ${deinstallfile} > ${deinstallfile}.tmp
    mv ${deinstallfile}.tmp ${deinstallfile}

    chmod 755 ${deinstallfile}

    mecho "deinstalling previously installed software ..."
    /var/install/bin/del-package -p ${module_name} --update
fi

exit 0
