#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/vbox-update.sh - update or generate new vbox configuration
#
# Copyright (c) 2002-2014 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2005-01-09  jed
# Last Update:  $Id: vbox-update.sh 36075 2014-09-12 10:08:31Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."

    # v1.0.3
    if [ ${VBOX_USER_N} -eq 0 ]
    then
        imax=2
    else
        imax=${VBOX_USER_N}
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        if [ ! -z "`grep ^VBOX_USER_${idx}_PORT $source_conf`" ]
        then
            eval port='$VBOX_USER_'$idx'_PORT'

            mecho "- VBOX_USER_${idx}_PORT -> VBOX_USER_${idx}_ISDN_PORT"
            eval "VBOX_USER_${idx}_ISDN_PORT=\"$port\""
            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_MSN $source_conf`" ]
        then
            eval msn='$VBOX_USER_'$idx'_MSN'

            mecho "- VBOX_USER_${idx}_MSN -> VBOX_USER_${idx}_ISDN_MSN"
            eval "VBOX_USER_${idx}_ISDN_MSN=\"$msn\""
            renamed=1
        fi

        # v1.0.6
        if [ ! -z "`grep ^VBOX_USER_${idx}_CID_UNKNOWN $source_conf`" ]
        then
            eval tmpstr='$VBOX_USER_'$idx'_CID_UNKNOWN'

            mecho "- VBOX_USER_${idx}_CID_UNKNOWN -> VBOX_USER_${idx}_CALLERID_UNKNOWN"
            eval "VBOX_USER_${idx}_CALLERID_UNKNOWN=\"$tmpstr\""
            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_CID_N $source_conf`" ]
        then
            eval cidnbr='$VBOX_USER_'$idx'_CID_N'

            mecho "- VBOX_USER_${idx}_CID_N -> VBOX_USER_${idx}_CALLERID_N"
            eval "VBOX_USER_${idx}_CALLERID_N=\"$cidnbr\""

            cidx=1
            while [ $cidx -le $cidnbr ]
            do
                if [ ! -z "`grep ^VBOX_USER_${idx}_CID_${cidx}_PATTERN $source_conf`" ]
                then
                    eval tmpstr='$VBOX_USER_'$idx'_CID_'${cidx}'_PATTERN'

                    mecho "- VBOX_USER_${idx}_CID_${cidx}_PATTERN -> VBOX_USER_${idx}_CALLERID_${cidx}_PATTERN"
                    eval "VBOX_USER_${idx}_CALLERID_${cidx}_PATTERN=\"$tmpstr\""
                    renamed=1
                fi

                if [ ! -z "`grep ^VBOX_USER_${idx}_CID_${cidx}_SECTION $source_conf`" ]
                then
                    eval tmpstr='$VBOX_USER_'$idx'_CID_'${cidx}'_SECTION'

                    mecho "- VBOX_USER_${idx}_CID_${cidx}_SECTION -> VBOX_USER_${idx}_CALLERID_${cidx}_SECTION_NAME"
                    eval "VBOX_USER_${idx}_CALLERID_${cidx}_SECTION_NAME=\"$tmpstr\""
                    renamed=1
                fi

                if [ ! -z "`grep ^VBOX_USER_${idx}_CID_${cidx}_REALNAME $source_conf`" ]
                then
                    eval tmpstr='$VBOX_USER_'$idx'_CID_'${cidx}'_REALNAME'

                    mecho "- VBOX_USER_${idx}_CID_${cidx}_REALNAME -> VBOX_USER_${idx}_CALLERID_${cidx}_REALNAME"
                    eval "VBOX_USER_${idx}_CALLERID_${cidx}_REALNAME=\"$tmpstr\""
                    renamed=1
                fi

                cidx=`expr $cidx + 1`
            done

            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_RING_DEF_COUNT $source_conf`" ]
        then
            eval tmpstr='$VBOX_USER_'$idx'_RING_DEF_COUNT'

            mecho "- VBOX_USER_${idx}_RING_DEF_COUNT -> VBOX_USER_${idx}_RING_STANDARD_RINGS"
            eval "VBOX_USER_${idx}_RING_STANDARD_RINGS=\"$tmpstr\""
            renamed=1
        fi

        eval ringnbr='$VBOX_USER_'$idx'_RING_N'

        ridx=1
        while [ $ridx -le $ringnbr ]
        do
            if [ ! -z "`grep ^VBOX_USER_${idx}_RING_${ridx}_COUNT $source_conf`" ]
            then
                eval tmpstr='$VBOX_USER_'$idx'_RING_'${ridx}'_COUNT'

                mecho "- VBOX_USER_${idx}_RING_${ridx}_COUNT -> VBOX_USER_${idx}_RING_${ridx}_RINGS"
                eval "VBOX_USER_${idx}_RING_${ridx}_RINGS=\"$tmpstr\""
                renamed=1
            fi

            ridx=`expr $ridx + 1`
        done

        # v1.0.9
        if [ ! -z "`grep ^VBOX_USER_${idx}_PASSWORD $source_conf`" ]
        then
            eval tmpstr='$VBOX_USER_'$idx'_PASSWORD'

            mecho "- VBOX_USER_${idx}_PASSWORD -> VBOX_USER_${idx}_PASS"
            eval "VBOX_USER_${idx}_PASS=\"$tmpstr\""
            renamed=1
        fi

        # v1.0.14
        if [ ! -z "`grep ^VBOX_USER_${idx}_SEND_MAIL ${source_conf}`" ]
        then
            # parameter splitted into two separate parameters
            # VBOX_USER_x_SEND_MAIL (no, subject, mail, attach)
            # -> VBOX_USER_x_MAIL_ENABLED (yes, no)
            # -> VBOX_USER_x_MAIL_TYPE    (subject, mail, attach)

            eval tmpstr='$VBOX_USER_'${idx}'_SEND_MAIL'

            mecho "- VBOX_USER_${idx}_SEND_MAIL -> VBOX_USER_${idx}_MAIL_ENABLED"

            if [ "${tmpstr}" = "no" ]
            then
                eval "VBOX_USER_${idx}_MAIL_ENABLED='no'"
            else
                eval "VBOX_USER_${idx}_MAIL_ENABLED='yes'"
            fi
            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_SEND_ADDR ${source_conf}`" ]
        then
            eval tmpstr='$VBOX_USER_'${idx}'_SEND_ADDR'

            mecho "- VBOX_USER_${idx}_SEND_ADDR -> VBOX_USER_${idx}_MAIL_ADDR"
            eval "VBOX_USER_${idx}_MAIL_ADDR=\"${tmpstr}\""
            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_SEND_SUBJECT ${source_conf}`" ]
        then
            eval tmpstr='$VBOX_USER_'${idx}'_SEND_SUBJECT'

            mecho "- VBOX_USER_${idx}_SEND_SUBJECT -> VBOX_USER_${idx}_MAIL_SUBJECT"
            eval "VBOX_USER_${idx}_MAIL_SUBJECT=\"${tmpstr}\""
            renamed=1
        fi

        if [ ! -z "`grep ^VBOX_USER_${idx}_SEND_SOUND_FORMAT ${source_conf}`" ]
        then
            eval tmpstr='$VBOX_USER_'${idx}'_SEND_SOUND_FORMAT'

            mecho "- VBOX_USER_${idx}_SEND_SOUND_FORMAT -> VBOX_USER_${idx}_MAIL_SOUND_FORMAT"
            eval "VBOX_USER_${idx}_MAIL_SOUND_FORMAT=\"${tmpstr}\""
            renamed=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${renamed} -eq 1 ]
    then
        mecho --info "... read documentation for renamed parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."

    vbox_debug=`echo $VBOX_DEBUGLEVEL|tr '[A-Z]' '[a-z]'`
    if [ "$vbox_debug" != "$VBOX_DEBUGLEVEL" ]
    then
        mecho "-VBOX_DEBUGLEVEL, '$VBOX_DEBUGLEVEL' -> '$vbox_debug'"
        eval "VBOX_DEBUGLEVEL=\"$vbox_debug\""
        modified=1
    fi

    if [ $VBOX_USER_N -eq 0 ]
    then
        imax=2
    else
        imax=$VBOX_USER_N
    fi

    idx=1
    while [ $idx -le $imax ]
    do
        eval port='$VBOX_USER_'$idx'_ISDN_PORT'

        echo "$port"|grep -q "/dev/"

        if [ $? -ne 0 ]
        then
            mecho "-VBOX_USER_${idx}_ISDN_PORT, '$port' -> '/dev/$port'"
            eval "VBOX_USER_${idx}_ISDN_PORT=\"/dev/$port\""
            modified=1
        fi

        # v1.0.6
        eval cid_nbr='$VBOX_USER_'$idx'_CALLERID_N'

        cdx=1
        while [ $cdx -le $cid_nbr ]
        do
            eval cid_name='$VBOX_USER_'$idx'_CALLERID_'$cdx'_SECTION_NAME'

            echo $cid_name|grep -q "^-"

            if [ $? -eq 0 ]
            then
                mecho "-VBOX_USER_${idx}_CALLERID_${cdx}_SECTION_NAME, '$cid_name' -> 'standard-owner'"
                eval "VBOX_USER_${idx}_CALLERID_${cdx}_SECTION_NAME=\"standard-owner\""
                modified=1
            fi

            cdx=`expr $cdx + 1`
        done

        # v1.0.14
        eval tmpstr='$VBOX_USER_'${idx}'_MAIL_ENABLED'

        if [ "${tmpstr}" != "" ]
        then
            # parameter splitted into two separate parameters
            # -> VBOX_USER_x_MAIL_ENABLED (yes, no)
            # -> VBOX_USER_x_MAIL_TYPE    (subject, mail, attach)

            if [ "${tmpstr}" != "no" -a "${tmpstr}" != "yes" ]
            then
                mecho "-VBOX_USER_${idx}_MAIL_ENABLED, '${tmpstr}' -> 'yes'"
                eval "VBOX_USER_${idx}_MAIL_ENABLED='yes'"
                modified=1
            fi
        fi

        idx=`expr $idx + 1`
    done

    if [ $modified -eq 1 ]
    then
        mecho --info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
pre_add_variables ()
{
    added=0
    mecho "pre-adding new parameter(s) ..."

    # v1.0.14
    if [ ${VBOX_USER_N} -eq 0 ]
    then
        imax=2
    else
        imax=${VBOX_USER_N}
    fi

    idx=1
    while [ ${idx} -le ${imax} ]
    do
        if [ -z "`grep ^VBOX_USER_${idx}_MAIL_TYPE ${source_conf}`" ]
        then
            # parameter splitted into two separate parameters
            # VBOX_USER_x_SEND_MAIL (no, subject, mail, attach)
            # -> VBOX_USER_x_MAIL_ENABLED (yes, no)
            # -> VBOX_USER_x_MAIL_TYPE    (subject, mail, attach)

            eval tmpstr1='$VBOX_USER_'${idx}'_SEND_MAIL'
            eval tmpstr2='$VBOX_USER_'${idx}'_MAIL_ENABLED'

            if [ "${tmpstr1}" != "" ]
            then
                # old parameter exists, read value
                if [ "${tmpstr1}" != "no" ]
                then
                    # take over previous value
                    mecho "- VBOX_USER_${idx}_MAIL_TYPE='${tmpstr1}'"
                    eval 'VBOX_USER_'${idx}'_MAIL_TYPE'="${tmpstr1}"
                else
                    # set default value
                    mecho "- VBOX_USER_${idx}_MAIL_TYPE='subject'"
                    eval 'VBOX_USER_'${idx}'_MAIL_TYPE'='subject'
                fi
            elif [ "${tmpstr2}" != "" ]
            then
                # new parameter exists, read value
                if [ "${tmpstr2}" != "no" ]
                then
                    # take over previous value
                    mecho "- VBOX_USER_${idx}_MAIL_TYPE='${tmpstr2}'"
                    eval 'VBOX_USER_'${idx}'_MAIL_TYPE'="${tmpstr2}"
                else
                    # set default value
                    mecho "- VBOX_USER_${idx}_MAIL_TYPE='subject'"
                    eval 'VBOX_USER_'${idx}'_MAIL_TYPE'='subject'
                fi
            fi

            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${added} -eq 1 ]
    then
        mecho --info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

    # v1.0.4
    if [ -z "`grep ^VBOX_TYPE $source_conf`" ]
    then
        mecho "- VBOX_TYPE='isdn'"
        VBOX_TYPE='isdn'
        added=1
    fi

    # v1.0.15
    if [ -z "`grep ^VBOX_TRUSTED_NETS_N ${source_conf}`" ]
    then
        mecho "- VBOX_TRUSTED_NETS_N='1'"
        VBOX_TRUSTED_NETS_N='1'
        added=1

        if [ -z "`grep ^VBOX_TRUSTED_NETS_1 ${source_conf}`" ]
        then
            # load configuration
            . ${basefile}

            # calculate netmask
            netmask=`netcalc netmaskbits "${IP_ETH_1_NETWORK}:${IP_ETH_1_NETMASK}"`

            # vboxd.conf format: 192.168.1.0/24
            mecho "- VBOX_TRUSTED_NETS_1='${IP_ETH_1_NETWORK}/${netmask}'"
            eval 'VBOX_TRUSTED_NETS_1='${IP_ETH_1_NETWORK}'/'${netmask}
        fi
    fi

    # v1.0.6
    if [ $VBOX_USER_N -eq 0 ]
    then
        imax=2
    else
        imax=$VBOX_USER_N
    fi

    idx=1
    while [ $idx -le $imax ]
    do
        if [ -z "`grep ^VBOX_USER_${idx}_ACTIVE $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_ACTIVE='no'"
            eval 'VBOX_USER_'${idx}'_ACTIVE'='no'
            added=1
        fi

        # 1.0.13
        if [ -z "`grep ^VBOX_USER_${idx}_NUMBER_PREFIX $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_NUMBER_PREFIX=''"
            eval 'VBOX_USER_'${idx}'_NUMBER_PREFIX'=""
            added=1
        fi

        # v1.0.6 / v1.0.14
        eval tmpstr='$VBOX_USER_'${idx}'_MAIL_ENABLED'

        if [ "${tmpstr}" = "" ]
        then
            # parameter haven't been renamed, create it
            if [ -z "`grep ^VBOX_USER_${idx}_MAIL_ENABLED ${source_conf}`" ]
            then
                mecho "- VBOX_USER_${idx}_MAIL_ENABLED='no'"
                eval 'VBOX_USER_'${idx}'_MAIL_ENABLED'='no'
                added=1
            fi

            if [ -z "`grep ^VBOX_USER_${idx}_MAIL_ADDR ${source_conf}`" ]
            then
                mecho "- VBOX_USER_${idx}_MAIL_ADDR='frank@local.lan'"
                eval 'VBOX_USER_'${idx}'_MAIL_ADDR'='frank@local.lan'
                added=1
            fi

            if [ -z "`grep ^VBOX_USER_${idx}_MAIL_SUBJECT ${source_conf}`" ]
            then
                mecho "- VBOX_USER_${idx}_MAIL_SUBJECT='New message from %cname (%cid)'"
                eval 'VBOX_USER_'${idx}'_MAIL_SUBJECT'="\"New message from %cname (%cid)\""
                added=1
            fi

            if [ -z "`grep ^VBOX_USER_${idx}_MAIL_SOUND_FORMAT ${source_conf}`" ]
            then
                mecho "- VBOX_USER_${idx}_MAIL_SOUND_FORMAT='wav'"
                eval 'VBOX_USER_'${idx}'_MAIL_SOUND_FORMAT'='wav'
                added=1
            fi
        fi

        # v1.0.6
        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_DEF_RECTIME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_DEF_RECTIME='90'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_DEF_RECTIME'='90'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_DEF_RINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_DEF_RINGS='3'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_DEF_RINGS'='3'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_DEF_TOLLRINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_DEF_TOLLRINGS='4'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_DEF_TOLLRINGS'='4'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_N $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_N='0'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_N'='0'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_TIME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_TIME='20:15-22:14'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_TIME'='20:15-22:14'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_DAYS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_DAYS='DO'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_DAYS'='DO'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_MSGFILE $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_MSGFILE='aktex.msg'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_MSGFILE'='aktex.msg'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_RECTIME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_RECTIME='60'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_RECTIME'='60'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_RINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_RINGS='1'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_RINGS'='1'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_1_TOLLRINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_STANDARD_1_TOLLRINGS='4'"
            eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_1_TOLLRINGS'='4'
            added=1
        fi

        eval vbox_nbr='$VBOX_USER_'${idx}'_SECTION_STANDARD_N'

        if [ $vbox_nbr -eq 0 ]
        then
            jmax=1
        else
            jmax=$vbox_nbr
        fi

        jdx=1
        while [ $jdx -le $jmax ]
        do
            if [ -z "`grep ^VBOX_USER_${idx}_SECTION_STANDARD_${jdx}_OPTION $source_conf`" ]
            then
              # mecho "- VBOX_USER_${idx}_SECTION_STANDARD_${jdx}_OPTION=''"   # optional 'hidden' parameter, 20.02.2005 jed
                eval 'VBOX_USER_'${idx}'_SECTION_STANDARD_'${jdx}'_OPTION'=''
              # added=1
            fi

            jdx=`expr $jdx + 1`
        done

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_N $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_N='0'"
            eval 'VBOX_USER_'${idx}'_SECTION_N'='0'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_NAME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_NAME='standard-owner'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_NAME'='standard-owner'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_N $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_N='1'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_N'='1'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_TIME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_TIME='*'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_TIME'='*'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_DAYS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_DAYS='*'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_DAYS'='*'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_MSGFILE $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_MSGFILE='standard.msg'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_MSGFILE'='standard.msg'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_RECTIME $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_RECTIME='120'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_RECTIME'='120'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_RINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_RINGS='99'"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_RINGS'='99'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_SECTION_1_ENTRY_1_TOLLRINGS $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SECTION_1_ENTRY_1_TOLLRINGS=''"
            eval 'VBOX_USER_'${idx}'_SECTION_1_ENTRY_1_TOLLRINGS'=''
            added=1
        fi

        eval vbox_nbr='$VBOX_USER_'${idx}'_SECTION_N'

        if [ $vbox_nbr -eq 0 ]
        then
            jmax=1
        else
            jmax=$vbox_nbr
        fi

        jdx=1
        while [ $jdx -le $jmax ]
        do
            eval vbox_nbr2='$VBOX_USER_'${idx}'_SECTION_'${jdx}'_ENTRY_N'

            if [ $vbox_nbr2 -eq 0 ]
            then
                kmax=1
            else
                kmax=$vbox_nbr2
            fi

            kdx=1
            while [ $kdx -le $kmax ]
            do
                if [ -z "`grep ^VBOX_USER_${idx}_SECTION_${jdx}_ENTRY_${kdx}_OPTION $source_conf`" ]
                then
                  # mecho "- VBOX_USER_${idx}_SECTION_${jdx}_ENTRY_${kdx}_OPTION=''" # optional 'hidden' parameter, 20.02.2005 jed
                    eval 'VBOX_USER_'${idx}'_SECTION_'${jdx}'_ENTRY_'${kdx}'_OPTION'=''
                  # added=1
                fi

                kdx=`expr $kdx + 1`
            done

            jdx=`expr $jdx + 1`
        done

        # v1.0.14
        if [ -z "`grep ^VBOX_USER_${idx}_CALL_ENABLED ${source_conf}`" ]
        then
            mecho "- VBOX_USER_${idx}_CALL_ENABLED='no'"
            eval 'VBOX_USER_'${idx}'_CALL_ENABLED'='no'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_CALL_NUMBER ${source_conf}`" ]
        then
            mecho "- VBOX_USER_${idx}_CALL_NUMBER=''"
            eval 'VBOX_USER_'${idx}'_CALL_NUMBER'=''
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_RSS_ENABLED ${source_conf}`" ]
        then
            mecho "- VBOX_USER_${idx}_RSS_ENABLED='no'"
            eval 'VBOX_USER_'${idx}'_RSS_ENABLED'='no'
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_RSS_SUBJECT ${source_conf}`" ]
        then
            mecho "- VBOX_USER_${idx}_RSS_SUBJECT='New message from %cname (%cid)'"
            eval 'VBOX_USER_'${idx}'_RSS_SUBJECT'="\"New message from %cname (%cid)\""
            added=1
        fi

        if [ -z "`grep ^VBOX_USER_${idx}_CALLERID_LOOKUP ${source_conf}`" ]
        then
            mecho "- VBOX_USER_${idx}_CALLERID_LOOKUP='no'"
            eval 'VBOX_USER_'${idx}'_CALLERID_LOOKUP'='no'
            added=1
        fi

        idx=`expr ${idx} + 1`
    done

    if [ ${added} -eq 1 ]
    then
        mecho --info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

    # v1.0.6
    if [ $VBOX_USER_N -eq 0 ]
    then
        imax=2
    else
        imax=$VBOX_USER_N
    fi

    idx=1
    while [ $idx -le $imax ]
    do
        if [ ! -z "`grep \"^VBOX_USER_${idx}_SMTP_ALIAS\" $source_conf`" ]
        then
            mecho "- VBOX_USER_${idx}_SMTP_ALIAS"
            deleted=1
        fi

        idx=`expr $idx + 1`
    done

    if [ $deleted -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "vbox" "2002-02-27" "jed"
        #------------------------------------------------------------------------------

        if [ "${VBOX_DO_DEBUG}" = "yes" -o "${VBOX_DO_DEBUG}" = "no" ]
        then
            # debug active
            printvar "VBOX_DO_DEBUG" "debug mode: yes or no"
            echo
        else
            # debug parameter exists but not active
            if [ -n "`grep VBOX_DO_DEBUG ${source_conf}`" ]
            then
                echo "# VBOX_DO_DEBUG='yes'                   # debug mode: yes or no"
                echo
            fi
        fi

        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------

        printvar "START_VBOX"              "start vbox daemon: yes or no"
        echo

        printvar "VBOX_TRUSTED_NETS_N"     "number of trusted nets or hosts"

        if [ ${VBOX_TRUSTED_NETS_N} -eq 0 ]
        then
            imax=1
        else
            imax=${VBOX_TRUSTED_NETS_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            printvar "VBOX_TRUSTED_NETS_${idx}"            "${idx}. net or host"

            idx=`expr ${idx} + 1`
        done

        echo
        printvar "VBOX_TYPE"               "vbox type: 'analog' or 'isdn'"

        if [ "${VBOX_COMPRESSION}" != "" ]
        then
            printvar "VBOX_COMPRESSION"    "used voice compr. level: adpcm-2/3/4 = 2/3/4 kb/s, ulaw"
        fi

        if [ "${VBOX_UMASK}" != "" ]
        then
            printvar "VBOX_UMASK"          "used file creation mask"
        fi

        printvar "VBOX_FREESPACE"          "if space < freespace a call isn't accepted"
        printvar "VBOX_DEBUGLEVEL"         "FEWIDJ means "log everything", -> see docs"

        #------------------------------------------------------------------------------
        printgroup "user malboxe(s)"
        #------------------------------------------------------------------------------

        printvar "VBOX_USER_N"             "number of voice mailboxes"

        if [ ${VBOX_USER_N} -eq 0 ]
        then
            imax=2
        else
            imax=${VBOX_USER_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            if [ ${idx} -gt 1 ]
            then
                echo '#----------------------------------------------------------------------------------'
            else
                echo
            fi

            printvar "VBOX_USER_${idx}_ACTIVE"            "${idx}. active entry: yes or no"
            printvar "VBOX_USER_${idx}_ISDN_PORT"         "   device port"
            printvar "VBOX_USER_${idx}_ISDN_MSN"          "   answer call on MSN"
            printvar "VBOX_USER_${idx}_NAME"              "   username"
            printvar "VBOX_USER_${idx}_GROUP"             "   group"
            printvar "VBOX_USER_${idx}_PASS"              "   password"
            printvar "VBOX_USER_${idx}_NUMBER_PREFIX"     "   number prefix, e.g. '0'"
            printvar "VBOX_USER_${idx}_CALL_ENABLED"      "   force call: yes or no"
            printvar "VBOX_USER_${idx}_CALL_NUMBER"       "   number to call"
            printvar "VBOX_USER_${idx}_MAIL_ENABLED"      "   send msg: yes or no"
            printvar "VBOX_USER_${idx}_MAIL_TYPE"         "   msg type: subject, mail, attach"
            printvar "VBOX_USER_${idx}_MAIL_ADDR"         "   mail to address"
            printvar "VBOX_USER_${idx}_MAIL_SUBJECT"      "   mail subject"
            printvar "VBOX_USER_${idx}_MAIL_SOUND_FORMAT" "   format of voice file to attach"
            printvar "VBOX_USER_${idx}_RSS_ENABLED"       "   create rss: yes or no"
            printvar "VBOX_USER_${idx}_RSS_SUBJECT"       "   rss subject"
            echo

            # CID
            printvar "VBOX_USER_${idx}_CALLERID_UNKNOWN"  "   unknown caller-id string"
            printvar "VBOX_USER_${idx}_CALLERID_LOOKUP"   "   lookup caller-id"
            printvar "VBOX_USER_${idx}_CALLERID_N"        "   number of caller-ids"

            eval cid_nbr='$VBOX_USER_'${idx}'_CALLERID_N'

            if [ ${cid_nbr} -eq 0 ]
            then
                jmax=2
            else
                jmax=${cid_nbr}
            fi

            jdx=1
            while [ ${jdx} -le ${jmax} ]
            do
                printvar "VBOX_USER_${idx}_CALLERID_${jdx}_PATTERN"      "   ${jdx}. number pattern"
                printvar "VBOX_USER_${idx}_CALLERID_${jdx}_SECTION_NAME" "      name of config section"
                printvar "VBOX_USER_${idx}_CALLERID_${jdx}_REALNAME"     "      real name to display"

                jdx=`expr ${jdx} + 1`
            done

            echo

            # rings
            printvar "VBOX_USER_${idx}_RING_STANDARD_RINGS" "   default number of rings"
            printvar "VBOX_USER_${idx}_RING_N"              "   number of ring settings"

            eval ring_nbr='$VBOX_USER_'${idx}'_RING_N'

            if [ ${ring_nbr} -eq 0 ]
            then
                jmax=1
            else
                jmax=${ring_nbr}
            fi

            jdx=1
            while [ ${jdx} -le ${jmax} ]
            do
                printvar "VBOX_USER_${idx}_RING_${jdx}_TIME"  "   ${jdx}. time"
                printvar "VBOX_USER_${idx}_RING_${jdx}_DAYS"  "      days"
                printvar "VBOX_USER_${idx}_RING_${jdx}_RINGS" "      number of rings"

                jdx=`expr ${jdx} + 1`
            done
            echo

            printvar "VBOX_USER_${idx}_SECTION_STANDARD_DEF_RECTIME"   "   def. recording time"
            printvar "VBOX_USER_${idx}_SECTION_STANDARD_DEF_RINGS"     "   def. number of rings"
            printvar "VBOX_USER_${idx}_SECTION_STANDARD_DEF_TOLLRINGS" "   def. number of toll rings"

            printvar "VBOX_USER_${idx}_SECTION_STANDARD_N"             "   number of standard entries"

            eval sec_nbr='$VBOX_USER_'${idx}'_SECTION_STANDARD_N'

            if [ ${sec_nbr} -eq 0 ]
            then
                smax=1
            else
                smax=${sec_nbr}
            fi

            sdx=1
            while [ ${sdx} -le ${smax} ]
            do
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_TIME"       "   ${sdx}. time"
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_DAYS"       "   ${sdx}. days"
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_MSGFILE"    "      name of message file"
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_RECTIME"    "      recording time"
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_RINGS"      "      number of rings"
                printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_TOLLRINGS"  "      number of toll rings"

                eval sec_option='$VBOX_USER_'${idx}'_SECTION_STANDARD_'${sdx}'_OPTION'

                if [ "${sec_option}" != "" ]
                then
                    printvar "VBOX_USER_${idx}_SECTION_STANDARD_${sdx}_OPTION" "      optional parameters"
                fi

                sdx=`expr ${sdx} + 1`
            done

            echo

            printvar "VBOX_USER_${idx}_SECTION_N" "      number of user sections"

            eval sec_nbr='$VBOX_USER_'${idx}'_SECTION_N'

            if [ ${sec_nbr} -eq 0 ]
            then
                smax=1
            else
                smax=${sec_nbr}
            fi

            sdx=1
            while [ ${sdx} -le ${smax} ]
            do
                printvar "VBOX_USER_${idx}_SECTION_${sdx}_NAME"    "      section name"
                printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_N" "   ${sdx}. number of entries"

                eval entry_nbr='$VBOX_USER_'${idx}'_SECTION_'${sdx}'_ENTRY_N'

                if [ ${entry_nbr} -eq 0 ]
                then
                    emax=1
                else
                    emax=${entry_nbr}
                fi

                edx=1
                while [ ${edx} -le ${emax} ]
                do
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_TIME"       "      time"
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_DAYS"       "      days"
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_MSGFILE"    "      name of message file"
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_RECTIME"    "      recording time"
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_RINGS"      "      number of rings"
                    printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_TOLLRINGS"  "      number of toll rings"

                    eval entry_option='$VBOX_USER_'$idx'_SECTION_'$sdx'_ENTRY_'$edx'_OPTION'

                    if [ "${entry_option}" != "" ]
                    then
                        printvar "VBOX_USER_${idx}_SECTION_${sdx}_ENTRY_${edx}_OPTION" "      optional parameters"
                    fi

                    edx=`expr ${edx} + 1`
                done

                sdx=`expr ${sdx} + 1`
            done

            idx=`expr ${idx} + 1`
        done

        echo
        echo '#----------------------------------------------------------------------------------'
        echo '# log handling'
        echo '#'
        echo '# Here you can specify how many logs should be saved and in with interval.'
        echo '#'
        echo '# Example:'
        echo "#   VBOX_LOG_COUNT='10'       - save the last 10 log files"
        echo "#   VBOX_LOG_INTERVAL='daily' - save one log file per day"
        echo '#----------------------------------------------------------------------------------'
        echo

        printvar "VBOX_LOG_COUNT"                  "number of log files to save"
        printvar "VBOX_LOG_INTERVAL"               "interval: daily, weekly, monthly"

        #------------------------------------------------------------------------------
        printend
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedvbox
 testroot=''

basefile=${testroot}/etc/config.d/base
vboxfile=$testroot/etc/config.d/vbox
installfile=/var/run/vbox.install

# setting defaults
source_conf=$installfile
generate_conf=$vboxfile

goflag=0

case "$1"
in
    update)
        goflag=1
        ;;
    test)
        source_conf=$vboxfile
      # source_conf=$installfile
      # source_conf=$testroot/etc/config.d/vbox

      # generate_conf=$testroot/etc/config.d/mk_vbox.test
        generate_conf=$installfile.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  vbox-update.sh [update] - the file $vboxfile.import will be read, the configuration will"
        mecho "                            be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ $goflag -eq 1 ]
then
    if [ -f $source_conf ]
    then
        # previous configuration file exists
        mecho --info "previous configuration found ..."
        . $source_conf

        pre_add_variables
        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else
        mecho --error "no configuration $source_conf found - exiting."
        anykey
    fi
fi

#==============================================================================
# end
#==============================================================================
